Crate oicana_template

Crate oicana_template 

Template abstraction for Oicana, a set of libraries and tools for document templating with Typst.

This crate contains a definition for Oicana template manifests and functionality to package a template.

Parts of this crate’s code are taken from the Typst package bundler under its Apache 2.0 License

Modules

manifest
Manifest of an Oicana template.
package
Method to package a template.

Structs

ExportConfig
Configuration for exporting compiled documents.
OicanaConfig
The relevant part of the tool section in an Oicana template manifest.
PdfExportConfig
Configuration for PDF export.

Enums

PdfStandard
A PDF standard that Typst can enforce conformance with.
TemplateError
Errors for reading and validating an Oicana template.

Functions

validate_native_template
Validate a native Oicana template given its path.