Template abstraction for Oicana, a set of libraries and tools for document templating with Typst.
This crate contains a definition for Oicana template manifests and functionality to package a template.
Parts of this crate’s code are taken from the Typst package bundler under its Apache 2.0 License
Modules
Structs
- Export
Config - Configuration for exporting compiled documents.
- Oicana
Config - The relevant part of the tool section in an Oicana template manifest.
- PdfExport
Config - Configuration for PDF export.
Enums
- PdfStandard
- A PDF standard that Typst can enforce conformance with.
- Template
Error - Errors for reading and validating an Oicana template.
Functions
- validate_
native_ template - Validate a native Oicana template given its path.